==> adms-2.2.4.tar.gz: adms-2.2.4/admsObject/objectRange.h <==

/* ------- code automatically created by ../scripts/adms_build_object.pl -------------- */

#ifndef objectrange_h
#define objectrange_h
#include <admsObject/admsH.h>
#include <admsObject/objectAdms.h>
typedef enum {
  adms_range_enumeration_type_exclude,
  adms_range_enumeration_type_include
} e_range_type;
win32_interface char* adms_range_tostring_type_impl (p_admsttransform myadmsttransform,e_range_type e);
win32_interface e_range_type adms_range_fromstring_type_impl (p_admsttransform myadmsttransform,char*token);
struct s_range {
  t_adms _adms;
  p_module _module;
  int _module_isdefault : 1;
  p_expression _infexpr;
  int _infexpr_isdefault : 1;
  p_expression _supexpr;
  int _supexpr_isdefault : 1;
  char* _name;
  int _name_isdefault : 1;
  char* _infboundtype;
  int _infboundtype_isdefault : 1;
  char* _supboundtype;
  int _supboundtype_isdefault : 1;
  e_range_type _type;
  int _type_isdefault : 1;
};
#include <admsObject/objectModule.h>
#include <admsObject/objectExpression.h>

#undef win32_interface
#if defined(WIN32)
#  if defined(_inside_admsObject)
#    define win32_interface __declspec(dllexport)
#  else
#    define win32_interface __declspec(dllimport)
#  endif
#else
#  define win32_interface extern
#endif

win32_interface char*adms_range_getuid (p_range myrange);
win32_interface gboolean adms_range_cmp (p_range myrange,p_range refrange);
win32_interface p_range adms_range_new_1 (p_module mymodule,p_expression myinfexpr,p_expression mysupexpr);
#define adms_range_free_debug(item)\
  adms_adms(item)->_freed=adms_adms_enumeration_freed_yes;
#define adms_range_free(item)\
{\
  free(item->_name);\
  free(item->_infboundtype);\
  free(item->_supboundtype);\
  free(item);\
}
win32_interface p_adms adms_range_new_impl (p_adms arguments[]);
win32_interface p_range adms_range_impl (void* member);
#define adms_range(member) ((p_range) (member))
#define adms_range_new adms_range_new_1
#define adms_range_isdefault_module(range) (adms_range(range)->_module_isdefault)
#define adms_range_valueof_module(range) (adms_range(range)->_module)
#define adms_range_isdefault_infexpr(range) (adms_range(range)->_infexpr_isdefault)
#define adms_range_valueof_infexpr(range) (adms_range(range)->_infexpr)
#define adms_range_isdefault_supexpr(range) (adms_range(range)->_supexpr_isdefault)
#define adms_range_valueof_supexpr(range) (adms_range(range)->_supexpr)
#define adms_range_isdefault_name(range) (adms_range(range)->_name_isdefault)
#define adms_range_valueof_name(range) (adms_range(range)->_name)
#define adms_range_isdefault_infboundtype(range) (adms_range(range)->_infboundtype_isdefault)
#define adms_range_valueof_infboundtype(range) (adms_range(range)->_infboundtype)
#define adms_range_isdefault_supboundtype(range) (adms_range(range)->_supboundtype_isdefault)
#define adms_range_valueof_supboundtype(range) (adms_range(range)->_supboundtype)
#define adms_range_isdefault_type(range) (adms_range(range)->_type_isdefault)
#define adms_range_valueof_type(range) (adms_range(range)->_type)
#define adms_range_valueof_adms(range) ((p_adms)range)
#define adms_range_valueto_module(a,b) ((p_range)a)->_module=(b)
win32_interface void adms_range_valueto_module_impl (p_range myrange,p_module _module);
#define adms_range_valueto_infexpr(a,b) ((p_range)a)->_infexpr=(b)
win32_interface void adms_range_valueto_infexpr_impl (p_range myrange,p_expression _infexpr);
#define adms_range_valueto_supexpr(a,b) ((p_range)a)->_supexpr=(b)
win32_interface void adms_range_valueto_supexpr_impl (p_range myrange,p_expression _supexpr);
#define adms_range_valueto_name(a,b) ((p_range)a)->_name=(b)
win32_interface void adms_range_valueto_name_impl (p_range myrange,char* _name);
#define adms_range_valueto_infboundtype(a,b) ((p_range)a)->_infboundtype=(b)
win32_interface void adms_range_valueto_infboundtype_impl (p_range myrange,char* _infboundtype);
#define adms_range_valueto_supboundtype(a,b) ((p_range)a)->_supboundtype=(b)
win32_interface void adms_range_valueto_supboundtype_impl (p_range myrange,char* _supboundtype);
#define adms_range_valueto_type(a,b) ((p_range)a)->_type=(b)
win32_interface void adms_range_valueto_type_impl (p_range myrange,e_range_type _type);
#endif /* objectrange_h */

==> adms-2.2.5.tar.gz: adms-2.2.5/admsObject/objectRange.h <==

/* ------- code automatically created by ../scripts/adms_build_object.pl -------------- */

#ifndef objectrange_h
#define objectrange_h
#include <admsObject/admsH.h>
#include <admsObject/objectAdms.h>
typedef enum {
  adms_range_enumeration_type_exclude,
  adms_range_enumeration_type_include
} e_range_type;
win32_interface char* adms_range_tostring_type_impl (p_admsttransform myadmsttransform,p_enumeration myenumeration);
win32_interface e_range_type adms_range_fromstring_type_impl (p_admsttransform myadmsttransform,char*token);
struct s_range {
  t_adms _adms;
  p_module _module;
  int _module_isdefault : 1;
  p_expression _infexpr;
  int _infexpr_isdefault : 1;
  p_expression _supexpr;
  int _supexpr_isdefault : 1;
  p_quark _name;
  int _name_isdefault : 1;
  p_quark _infboundtype;
  int _infboundtype_isdefault : 1;
  p_quark _supboundtype;
  int _supboundtype_isdefault : 1;
  p_enumeration _type;
  int _type_isdefault : 1;
};
#include <admsObject/objectModule.h>
#include <admsObject/objectExpression.h>
#include <admsObject/objectQuark.h>
#include <admsObject/objectEnumeration.h>

#undef win32_interface
#if defined(WIN32)
#  if defined(_inside_admsObject)
#    define win32_interface __declspec(dllexport)
#  else
#    define win32_interface __declspec(dllimport)
#  endif
#else
#  define win32_interface extern
#endif

win32_interface char*adms_range_uid (p_range myrange);
win32_interface int adms_range_cmp (p_range myrange,p_range refrange);
win32_interface p_range adms_range_new(p_module mymodule,p_expression myinfexpr,p_expression mysupexpr);
win32_interface p_adms adms_range_new_impl (p_adms arguments[]);
#define adms_range(member) ((p_range) (member))
#define adms_range_isdefault_module(range) (adms_range(range)->_module_isdefault)
#define adms_range_valueof_module(range) (adms_range(range)->_module)
#define adms_range_isdefault_infexpr(range) (adms_range(range)->_infexpr_isdefault)
#define adms_range_valueof_infexpr(range) (adms_range(range)->_infexpr)
#define adms_range_isdefault_supexpr(range) (adms_range(range)->_supexpr_isdefault)
#define adms_range_valueof_supexpr(range) (adms_range(range)->_supexpr)
#define adms_range_isdefault_name(range) (adms_range(range)->_name_isdefault)
#define adms_range_valueof_name(range) (adms_range(range)->_name)
#define adms_range_isdefault_infboundtype(range) (adms_range(range)->_infboundtype_isdefault)
#define adms_range_valueof_infboundtype(range) (adms_range(range)->_infboundtype)
#define adms_range_isdefault_supboundtype(range) (adms_range(range)->_supboundtype_isdefault)
#define adms_range_valueof_supboundtype(range) (adms_range(range)->_supboundtype)
#define adms_range_isdefault_type(range) (adms_range(range)->_type_isdefault)
#define adms_range_valueof_type(range) (adms_range(range)->_type)
#define adms_range_valueof_adms(range) ((p_adms)range)
win32_interface inline void adms_range_valueto_module (p_range myrange,p_module _module);
win32_interface inline void adms_range_valueto_infexpr (p_range myrange,p_expression _infexpr);
win32_interface inline void adms_range_valueto_supexpr (p_range myrange,p_expression _supexpr);
win32_interface inline void adms_range_valueto_name (p_range myrange,p_quark _name);
win32_interface inline void adms_range_valueto_infboundtype (p_range myrange,p_quark _infboundtype);
win32_interface inline void adms_range_valueto_supboundtype (p_range myrange,p_quark _supboundtype);
win32_interface inline void adms_range_valueto_type (p_range myrange,p_enumeration _type);
win32_interface inline void adms_range_free(p_range myrange);
#endif /* objectrange_h */
